<?php
/*
 *  Author: Todd Motto | @toddmotto
 *  URL: html5blank.com | @html5blank
 *  Custom functions, support, custom post types and more.
 */

/*------------------------------------*\
	External Modules/Files
\*------------------------------------*/

// Load any external files you have here

/*------------------------------------*\
	Theme Support
\*------------------------------------*/

require_once('library/multi-post-thumbnails.php');

if (class_exists('MultiPostThumbnails')) {
	new MultiPostThumbnails(array(
		'label' => 'Slide Featured Image',
		'id' => 'slide-featured-image',
		'post_type' => 'post'
		)
	);  
};

if (!isset($content_width))
{
		$content_width = 900;
}

if (function_exists('add_theme_support'))
{
		// Add Menu Support
		add_theme_support('menus');
    add_theme_support( "title-tag" );
		// Add Thumbnail Theme Support
		add_theme_support('post-thumbnails');
		add_image_size('blog-post', 730, 485, true);

		add_theme_support( 'custom-logo', array(
				'height'      => 123,
				'width'       => 442,
				'flex-height' => true,
				'flex-width'  => true,
				'header-text' => array( 'site-title', 'site-description' ),
		));

    add_theme_support('post-formats', array('video'));

		
		add_theme_support('custom-background', array(
		'default-color' => 'FFF',
		'default-image' => ''
		));

		// Add Support for Custom Header - Uncomment below if you're going to use
		/*add_theme_support('custom-header', array(
	'default-image'			=> get_template_directory_uri() . '/img/headers/default.jpg',
	'header-text'			=> false,
	'default-text-color'		=> '000',
	'width'				=> 1000,
	'height'			=> 198,
	'random-default'		=> false,
	'wp-head-callback'		=> $wphead_cb,
	'admin-head-callback'		=> $adminhead_cb,
	'admin-preview-callback'	=> $adminpreview_cb
		));*/

		// Enables post and comment RSS feed links to head
		add_theme_support('automatic-feed-links');

		// Localisation Support
		//load_theme_textdomain('html5blank', get_template_directory() . '/languages');
}

/*------------------------------------*\
	Functions
\*------------------------------------*/

// HTML5 Blank navigation
function header_nav()
{
	wp_nav_menu(
	array(
		'theme_location'  => 'header-menu',
		'menu'            => '',
		'container'       => 'div',
		'container_class' => 'menu-{menu slug}-container',
		'container_id'    => '',
		'menu_class'      => 'menu',
		'menu_id'         => '',
		'echo'            => true,
		'fallback_cb'     => 'wp_page_menu',
		'before'          => '',
		'after'           => '',
		'link_before'     => '',
		'link_after'      => '',
		'items_wrap'      => '<ul>%3$s</ul>',
		'depth'           => 0,
		'walker'          => ''
		)
	);
}

// Load HTML5 Blank scripts (header.php)
function html5blank_header_scripts()
{
		if ($GLOBALS['pagenow'] != 'wp-login.php' && !is_admin()) {

				wp_register_script('swiper-js', get_template_directory_uri() . '/js/lib/swiper/js/swiper.jquery.min.js', array('jquery'), '3.4.2');
        wp_enqueue_script('swiper-js'); // Enqueue it!

				wp_register_script('theme-script', get_template_directory_uri() . '/js/scripts.js', array('jquery'), '1.0.0'); // Custom scripts
				wp_enqueue_script('theme-script'); // Enqueue it!
		}
}

// Load HTML5 Blank conditional scripts
function html5blank_conditional_scripts()
{
		if (is_page('pagenamehere')) {
				wp_register_script('scriptname', get_template_directory_uri() . '/js/scriptname.js', array('jquery'), '1.0.0'); // Conditional script(s)
				wp_enqueue_script('scriptname'); // Enqueue it!
		}
}

// Load HTML5 Blank styles
function html5blank_styles()
{

		wp_register_style('font-awesome-css', get_template_directory_uri() . '/js/lib/font-awesome/css/font-awesome.min.css', array(), '4.7.0', 'all');
		wp_enqueue_style('font-awesome-css');

    wp_register_style('swiper-css', get_template_directory_uri() . '/js/lib/swiper/css/swiper.min.css', array(), '3.4.2', 'all');
    wp_enqueue_style('swiper-css'); // Enqueue it!

		wp_register_style('theme-styles', get_template_directory_uri() . '/style.css', array(), '1.0.1', 'all');
		wp_enqueue_style('theme-styles'); // Enqueue it!
}

// Register HTML5 Blank Navigation
function register_html5_menu()
{
		register_nav_menus(array( // Using array to specify more menus if needed
				'header-menu' => __('Header Menu', 'html5blank'), // Main Navigation
		));
}

// Remove the <div> surrounding the dynamic navigation to cleanup markup
function my_wp_nav_menu_args($args = '')
{
		$args['container'] = false;
		return $args;
}

// Remove Injected classes, ID's and Page ID's from Navigation <li> items
function my_css_attributes_filter($var)
{
		return is_array($var) ? array() : '';
}

// Remove invalid rel attribute values in the categorylist
function remove_category_rel_from_category_list($thelist)
{
		return str_replace('rel="category tag"', 'rel="tag"', $thelist);
}

// Add page slug to body class, love this - Credit: Starkers Wordpress Theme
function add_slug_to_body_class($classes)
{
		global $post;
		if (is_home()) {
				$key = array_search('blog', $classes);
				if ($key > -1) {
						unset($classes[$key]);
				}
		} elseif (is_page()) {
				$classes[] = sanitize_html_class($post->post_name);
		} elseif (is_singular()) {
				$classes[] = sanitize_html_class($post->post_name);
		}

		return $classes;
}

// If Dynamic Sidebar Exists
if (function_exists('register_sidebar'))
{
		register_sidebar(array(
				'name' => __('Sidebar', 'html5blank'),
				'id' => 'sidebar-widget',
				'before_widget' => '<div id="%1$s" class="%2$s sidebar-widget">',
				'after_widget' => '</div>',
				'before_title' => '<div class="widget-title">',
				'after_title' => '</div>'
		));

		register_sidebar(array(
				'name' => __('Footer', 'html5blank'),
				'id' => 'footer-widget',
				'before_widget' => '<div id="%1$s" class="%2$s footer-widget">',
				'after_widget' => '</div>',
				'before_title' => '<div class="footer-widget-title">',
				'after_title' => '</div>'
		));

		register_sidebar(array(
				'name' => __('Left ADS Block', 'html5blank'),
				'id' => 'ads-widget1',
				'before_widget' => '<div id="%1$s" class="%2$s top-ads-widget">',
				'after_widget' => '</div>',
				'before_title' => '<div class="widget-title">',
				'after_title' => '</div>'
		));

		register_sidebar(array(
				'name' => __('Right ADS Block', 'html5blank'),
				'id' => 'ads-widget2',
				'before_widget' => '<div id="%1$s" class="%2$s top-ads-widget">',
				'after_widget' => '</div>',
				'before_title' => '<div class="widget-title">',
				'after_title' => '</div>'
		));

}

// Remove wp_head() injected Recent Comment styles
function my_remove_recent_comments_style()
{
		global $wp_widget_factory;
		remove_action('wp_head', array(
				$wp_widget_factory->widgets['WP_Widget_Recent_Comments'],
				'recent_comments_style'
		));
}

// Pagination for paged posts, Page 1, Page 2, Page 3, with Next and Previous Links, No plugin
function html5wp_pagination()
{
		global $wp_query;
		$big = 999999999;
		echo paginate_links(array(
				'base' => str_replace($big, '%#%', get_pagenum_link($big)),
				'format' => '?paged=%#%',
				'current' => max(1, get_query_var('paged')),
				'total' => $wp_query->max_num_pages,
				'prev_text'          => '&#8592;',
				'next_text'          => '&#8594;'
		));
}

// Custom Excerpts
function html5wp_index($length) // Create 20 Word Callback for Index page Excerpts, call using html5wp_excerpt('html5wp_index');
{
		return 19;
}

// Create 40 Word Callback for Custom Post Excerpts, call using html5wp_excerpt('html5wp_custom_post');
function html5wp_custom_post($length)
{
		return 30;
}

// Create the Custom Excerpts callback
function html5wp_excerpt($length_callback = '', $more_callback = '')
{
		global $post;
		if (function_exists($length_callback)) {
				add_filter('excerpt_length', $length_callback);
		}
		if (function_exists($more_callback)) {
				add_filter('excerpt_more', $more_callback);
		}
		$output = get_the_excerpt();
		$output = apply_filters('wptexturize', $output);
		$output = apply_filters('convert_chars', $output);
		$output = '<p>' . $output . '</p>';
		echo $output;
}

// Custom View Article link to Post
function html5_blank_view_article($more)
{
		global $post;
		return '.';
}

// Remove Admin bar
function remove_admin_bar()
{
		return false;
}

// Remove 'text/css' from our enqueued stylesheet
function html5_style_remove($tag)
{
		return preg_replace('~\s+type=["\'][^"\']++["\']~', '', $tag);
}

// Remove thumbnail width and height dimensions that prevent fluid images in the_thumbnail
function remove_thumbnail_dimensions( $html )
{
		$html = preg_replace('/(width|height)=\"\d*\"\s/', "", $html);
		return $html;
}

// Custom Gravatar in Settings > Discussion
function html5blankgravatar ($avatar_defaults)
{
		$myavatar = get_template_directory_uri() . '/img/gravatar.jpg';
		$avatar_defaults[$myavatar] = "Custom Gravatar";
		return $avatar_defaults;
}

// Threaded Comments
function enable_threaded_comments()
{
		if (!is_admin()) {
				if (is_singular() AND comments_open() AND (get_option('thread_comments') == 1)) {
						wp_enqueue_script('comment-reply');
				}
		}
}

// Custom Comments Callback
function html5blankcomments($comment, $args, $depth)
{
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
?>
		<!-- heads up: starting < for the html tag (li or div) in the next line: -->
		<<?php echo $tag ?> <?php comment_class(empty( $args['has_children'] ) ? '' : 'parent') ?> id="comment-<?php comment_ID() ?>">
	<?php if ( 'div' != $args['style'] ) : ?>
	<div id="div-comment-<?php comment_ID() ?>" class="comment-body">
	<?php endif; ?>
	<div class="comment-author vcard">
	<?php if ($args['avatar_size'] != 0) echo get_avatar( $comment, $args['180'] ); ?>
	<?php printf(__('<cite class="fn">%s</cite> <span class="says">says:</span>', 'html5blank'), get_comment_author_link()) ?>
	</div>
<?php if ($comment->comment_approved == '0') : ?>
	<em class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'html5blank') ?></em>
	<br />
<?php endif; ?>

	<div class="comment-meta commentmetadata"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>">
		<?php
			printf( __('%1$s at %2$s', 'html5blank'), get_comment_date(),  get_comment_time()) ?></a><?php edit_comment_link(__('(Edit)', 'html5blank'),'  ','' );
		?>
	</div>

	<?php comment_text() ?>

	<div class="reply">
	<?php comment_reply_link(array_merge( $args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
	</div>
	<?php if ( 'div' != $args['style'] ) : ?>
	</div>
	<?php endif; ?>
<?php }

/*------------------------------------*\
	Actions + Filters + ShortCodes
\*------------------------------------*/

// Add Actions
add_action('init', 'html5blank_header_scripts'); // Add Custom Scripts to wp_head
add_action('wp_print_scripts', 'html5blank_conditional_scripts'); // Add Conditional Page Scripts
add_action('get_header', 'enable_threaded_comments'); // Enable Threaded Comments
add_action('wp_enqueue_scripts', 'html5blank_styles'); // Add Theme Stylesheet
add_action('init', 'register_html5_menu'); // Add HTML5 Blank Menu
// add_action('init', 'create_post_type_html5'); // Add our HTML5 Blank Custom Post Type
add_action('widgets_init', 'my_remove_recent_comments_style'); // Remove inline Recent Comment Styles from wp_head()
add_action('init', 'html5wp_pagination'); // Add our HTML5 Pagination

// Remove Actions
remove_action('wp_head', 'feed_links_extra', 3); // Display the links to the extra feeds such as category feeds
remove_action('wp_head', 'feed_links', 2); // Display the links to the general feeds: Post and Comment Feed
remove_action('wp_head', 'rsd_link'); // Display the link to the Really Simple Discovery service endpoint, EditURI link
remove_action('wp_head', 'wlwmanifest_link'); // Display the link to the Windows Live Writer manifest file.
remove_action('wp_head', 'index_rel_link'); // Index link
remove_action('wp_head', 'parent_post_rel_link', 10, 0); // Prev link
remove_action('wp_head', 'start_post_rel_link', 10, 0); // Start link
remove_action('wp_head', 'adjacent_posts_rel_link', 10, 0); // Display relational links for the posts adjacent to the current post.
remove_action('wp_head', 'wp_generator'); // Display the XHTML generator that is generated on the wp_head hook, WP version
remove_action('wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
remove_action('wp_head', 'rel_canonical');
remove_action('wp_head', 'wp_shortlink_wp_head', 10, 0);

// Add Filters
add_filter('avatar_defaults', 'html5blankgravatar'); // Custom Gravatar in Settings > Discussion
add_filter('body_class', 'add_slug_to_body_class'); // Add slug to body class (Starkers build)
add_filter('widget_text', 'do_shortcode'); // Allow shortcodes in Dynamic Sidebar
add_filter('widget_text', 'shortcode_unautop'); // Remove <p> tags in Dynamic Sidebars (better!)
add_filter('wp_nav_menu_args', 'my_wp_nav_menu_args'); // Remove surrounding <div> from WP Navigation
// add_filter('nav_menu_css_class', 'my_css_attributes_filter', 100, 1); // Remove Navigation <li> injected classes (Commented out by default)
// add_filter('nav_menu_item_id', 'my_css_attributes_filter', 100, 1); // Remove Navigation <li> injected ID (Commented out by default)
// add_filter('page_css_class', 'my_css_attributes_filter', 100, 1); // Remove Navigation <li> Page ID's (Commented out by default)
add_filter('the_category', 'remove_category_rel_from_category_list'); // Remove invalid rel attribute
add_filter('the_excerpt', 'shortcode_unautop'); // Remove auto <p> tags in Excerpt (Manual Excerpts only)
add_filter('the_excerpt', 'do_shortcode'); // Allows Shortcodes to be executed in Excerpt (Manual Excerpts only)
add_filter('excerpt_more', 'html5_blank_view_article'); // Add 'View Article' button instead of [...] for Excerpts

add_filter('style_loader_tag', 'html5_style_remove'); // Remove 'text/css' from enqueued stylesheet
add_filter('post_thumbnail_html', 'remove_thumbnail_dimensions', 10); // Remove width and height dynamic attributes to thumbnails
add_filter('image_send_to_editor', 'remove_thumbnail_dimensions', 10); // Remove width and height dynamic attributes to post images

// Remove Filters
remove_filter('the_excerpt', 'wpautop'); // Remove <p> tags from Excerpt altogether


function options_customize_register( $wp_customize ) {

	$wp_customize->add_section( 'colors_section', array(
		'title'          => 'Elements Colors',
		'priority'       => 134,
	));

		$wp_customize->add_setting( 'label_background', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'label_background', array(
			'label'   => 'Label Background',
			'section' => 'colors_section',
			'settings'   => 'label_background',
		)));

		$wp_customize->add_setting( 'slider_background', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'slider_background', array(
			'label'   => 'Slider Background',
			'section' => 'colors_section',
			'settings'   => 'slider_background',
		)));

	$wp_customize->add_section( 'footer_section' , array(
		'title'      => 'Footer',
		'priority'   => 135,
	));

		$wp_customize->add_setting( 'footer_copyright', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'footer_copyright', array(
			'label'   => 'Footer Copyright',
			'section' => 'footer_section',
			'settings'   => 'footer_copyright',
			'type'    => 'text',
			'priority' => 3
		));

		
	$wp_customize->add_section( 'social_section' , array(
		'title'      => 'Social',
		'priority'   => 135,
	));

		$wp_customize->add_setting( 'social_twitter', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_twitter', array(
			'label'   => 'Twitter',
			'section' => 'social_section',
			'settings'   => 'social_twitter',
			'type'    => 'text',
			'priority' => 3
		));

		$wp_customize->add_setting( 'social_facebook', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_facebook', array(
			'label'   => 'Facebook',
			'section' => 'social_section',
			'settings'   => 'social_facebook',
			'type'    => 'text',
			'priority' => 3
		));

		$wp_customize->add_setting( 'social_google', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_google', array(
			'label'   => 'Google +',
			'section' => 'social_section',
			'settings'   => 'social_google',
			'type'    => 'text',
			'priority' => 3
		));

		$wp_customize->add_setting( 'social_instagram', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_instagram', array(
			'label'   => 'Instagram',
			'section' => 'social_section',
			'settings'   => 'social_instagram',
			'type'    => 'text',
			'priority' => 3
		));

		$wp_customize->add_setting( 'social_pinterest', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_pinterest', array(
			'label'   => 'Pinterest',
			'section' => 'social_section',
			'settings'   => 'social_pinterest',
			'type'    => 'text',
			'priority' => 3
		));

		$wp_customize->add_setting( 'social_vimeo', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_vimeo', array(
			'label'   => 'Vimeo',
			'section' => 'social_section',
			'settings'   => 'social_vimeo',
			'type'    => 'text',
			'priority' => 3
		));	

		$wp_customize->add_setting( 'social_youtube', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_youtube', array(
			'label'   => 'Youtube',
			'section' => 'social_section',
			'settings'   => 'social_youtube',
			'type'    => 'text',
			'priority' => 3
		));	

		$wp_customize->add_setting( 'social_linkedin', array(
			'default'        => '',
			'sanitize_callback'	=> 'esc_attr',
		));

		$wp_customize->add_control( 'social_linkedin', array(
			'label'   => 'LinkedIn',
			'section' => 'social_section',
			'settings'   => 'social_linkedin',
			'type'    => 'text',
			'priority' => 3
		));	

}

add_action( 'customize_register', 'options_customize_register' );


add_action( 'add_meta_boxes', 'slide_post_box' );
add_action( 'save_post', 'slide_post_save_postdata' );

function slide_post_box() {
    add_meta_box( 
        'slider-post-id',
        'Show In Slider',
        'slide_post_callback',
        'post',
        'side',
        'default'
    );
}

function slide_post_callback($post)
{
    wp_nonce_field( 'slide_post_field_nonce', 'slide_post_noncename' );
    $saved = get_post_meta( $post->ID, 'home_slide_post', true);
    if( !$saved )
        $saved = 'default';

    $fields = array(
        'yes'       => __('Yes', 'wpse'),
        'default'   => __('No', 'wpse'),
    );

    foreach($fields as $key => $label)
    {
        printf(
            '<input type="radio" name="home_slide_post" value="%1$s" id="home_slide_post[%1$s]" %3$s />'.
            '<label for="home_slide_post[%1$s]"> %2$s ' .
            '</label><br>',
            esc_attr($key),
            esc_html($label),
            checked($saved, $key, false)
        );
    }
}

function slide_post_save_postdata( $post_id ) 
{
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
        return;

    if ( !wp_verify_nonce( $_POST['slide_post_noncename'], 'slide_post_field_nonce' ) )
        return;

    if ( isset($_POST['home_slide_post']) && $_POST['home_slide_post'] != "" ){
          update_post_meta( $post_id, 'home_slide_post', $_POST['home_slide_post'] );
    } 
}

function category_posts_pagination( $query ) 
{
	if ( is_category() && $query->is_main_query() ) 
	{
		$query->query_vars['posts_per_page'] = 9;
		return;
	}
	}
add_action( 'pre_get_posts', 'category_posts_pagination', 1 );

?>